summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2005-12-21 16:18:55 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2005-12-21 16:18:55 +0000
commit0ab0da2bb30decf8585be6ad3855b213051f1d3c (patch)
tree7d809a3597cbbb94f4cad2a0c6adae2d11de85b6
parentc0ecdfdd198c0deeb47f7c9d53e27c4c1292ccfc (diff)
downloadATCD-0ab0da2bb30decf8585be6ad3855b213051f1d3c.tar.gz
ChangeLogTag: Wed Dec 21 16:14:12 UTC 2005 Johnny Willemsen <jwillemsen@remedy.nl>
-rw-r--r--ace/Basic_Types.h7
-rw-r--r--ace/CDR_Base.cpp2
-rw-r--r--ace/CDR_Stream.cpp2
-rw-r--r--ace/Configuration_Import_Export.cpp2
-rw-r--r--ace/Malloc_T.cpp6
-rw-r--r--ace/OS_NS_sys_stat.inl2
-rw-r--r--ace/OS_NS_time.cpp2
-rw-r--r--ace/WIN32_Proactor.cpp15
-rw-r--r--ace/config-vxworks6.1.h11
-rw-r--r--bin/MakeProjectCreator/modules/BorlandProjectCreator.pm3
-rw-r--r--etc/tao.doxygen7
-rw-r--r--examples/Reactor/Misc/test_demuxing.cpp2
-rw-r--r--include/makeinclude/platform_linux_icc.GNU19
-rw-r--r--tests/Basic_Types_Test.cpp16
-rw-r--r--tests/Buffer_Stream_Test.cpp10
15 files changed, 52 insertions, 54 deletions
diff --git a/ace/Basic_Types.h b/ace/Basic_Types.h
index a0825e8a1a2..056edb3ccbf 100644
--- a/ace/Basic_Types.h
+++ b/ace/Basic_Types.h
@@ -290,14 +290,9 @@ typedef unsigned char ACE_Byte;
// Type for doing arithmetic on pointers ... as elsewhere, we assume
// that unsigned versions of a type are the same size as the signed
// version of the same type.
-// NOTE! ptr_arith_t is an ACE-defined type and should not be used.
-// It has been superseded by the standard type ptrdiff_t. This definition
-// is simply a placeholder til all ptr_arith_t usage can be expunged from
-// ACE and TAO.
# if defined (ACE_HAS_WINCE) && (_WIN32_WCE < 400)
-typedef unsigned long ptrdiff_t; // evc3, PocketPC don't defined ptrdiff_t
+typedef unsigned long ptrdiff_t; // evc3, PocketPC don't defined ptrdiff_t
# endif
-typedef ptrdiff_t ptr_arith_t;
ACE_END_VERSIONED_NAMESPACE_DECL
diff --git a/ace/CDR_Base.cpp b/ace/CDR_Base.cpp
index bd90ffbaefd..3fc530b5d1b 100644
--- a/ace/CDR_Base.cpp
+++ b/ace/CDR_Base.cpp
@@ -555,7 +555,7 @@ ACE_CDR::consolidate (ACE_Message_Block *dst,
ptrdiff_t(src->rd_ptr ()) % ACE_CDR::MAX_ALIGNMENT;
ptrdiff_t dstalign =
ptrdiff_t(dst->rd_ptr ()) % ACE_CDR::MAX_ALIGNMENT;
- int offset = srcalign - dstalign;
+ long offset = srcalign - dstalign;
if (offset < 0)
offset += ACE_CDR::MAX_ALIGNMENT;
dst->rd_ptr (offset);
diff --git a/ace/CDR_Stream.cpp b/ace/CDR_Stream.cpp
index 9a091f4f3fb..f0277500a8f 100644
--- a/ace/CDR_Stream.cpp
+++ b/ace/CDR_Stream.cpp
@@ -173,7 +173,7 @@ ACE_OutputCDR::grow_and_adjust (size_t size,
ptrdiff_t(tmp->rd_ptr ()) % ACE_CDR::MAX_ALIGNMENT;
ptrdiff_t curalign =
ptrdiff_t(this->current_alignment_) % ACE_CDR::MAX_ALIGNMENT;
- int offset = curalign - tmpalign;
+ long offset = curalign - tmpalign;
if (offset < 0)
offset += ACE_CDR::MAX_ALIGNMENT;
tmp->rd_ptr (offset);
diff --git a/ace/Configuration_Import_Export.cpp b/ace/Configuration_Import_Export.cpp
index aab75bf5654..76ad0f051d9 100644
--- a/ace/Configuration_Import_Export.cpp
+++ b/ace/Configuration_Import_Export.cpp
@@ -123,7 +123,7 @@ ACE_Registry_ImpExp::import_config (const ACE_TCHAR* filename)
{
// number type
ACE_TCHAR* endptr = 0;
- u_int value = ACE_OS::strtoul (end + 6, &endptr, 16);
+ unsigned long value = ACE_OS::strtoul (end + 6, &endptr, 16);
if (config_.set_integer_value (section, name, value))
{
ACE_OS::fclose (in);
diff --git a/ace/Malloc_T.cpp b/ace/Malloc_T.cpp
index 09be7afda35..63e33324201 100644
--- a/ace/Malloc_T.cpp
+++ b/ace/Malloc_T.cpp
@@ -80,7 +80,8 @@ ACE_Cached_Allocator<T, ACE_LOCK>::calloc (size_t nbytes,
// addr() call is really not absolutely necessary because of the way
// ACE_Cached_Mem_Pool_Node's internal structure arranged.
void *ptr = this->free_list_.remove ()->addr ();
- ACE_OS::memset (ptr, initial_value, sizeof (T));
+ if (ptr != 0)
+ ACE_OS::memset (ptr, initial_value, sizeof (T));
return ptr;
}
@@ -152,7 +153,8 @@ ACE_Dynamic_Cached_Allocator<ACE_LOCK>::calloc (size_t nbytes,
// addr() call is really not absolutely necessary because of the way
// ACE_Cached_Mem_Pool_Node's internal structure arranged.
void *ptr = this->free_list_.remove ()->addr ();
- ACE_OS::memset (ptr, initial_value, chunk_size_);
+ if (ptr != 0)
+ ACE_OS::memset (ptr, initial_value, chunk_size_);
return ptr;
}
diff --git a/ace/OS_NS_sys_stat.inl b/ace/OS_NS_sys_stat.inl
index a4af4a6cc86..9417fa9d141 100644
--- a/ace/OS_NS_sys_stat.inl
+++ b/ace/OS_NS_sys_stat.inl
@@ -215,7 +215,7 @@ namespace ACE_OS
#elif defined (ACE_WIN32) && defined (__IBMCPP__) && (__IBMCPP__ >= 400)
ACE_UNUSED_ARG (mode);
- ACE_OSCALL_RETURN (::_mkdir ((char *) path), int, -1);
+ ACE_OSCALL_RETURN (::_mkdir (const_cast <char *> (path)), int, -1);
#elif defined (ACE_HAS_WINCE)
ACE_UNUSED_ARG (mode);
ACE_WIN32CALL_RETURN (ACE_ADAPT_RETVAL (::CreateDirectory (ACE_TEXT_CHAR_TO_TCHAR (path), 0),
diff --git a/ace/OS_NS_time.cpp b/ace/OS_NS_time.cpp
index ffcce8dec0f..4db08ba9faa 100644
--- a/ace/OS_NS_time.cpp
+++ b/ace/OS_NS_time.cpp
@@ -461,7 +461,7 @@ ACE_OS::localtime_r (const time_t *t, struct tm *res)
res->tm_mday = systime.wDay;
res->tm_min = systime.wMinute;
- res->tm_mon = systime.wMonth;
+ res->tm_mon = systime.wMonth - 1;
res->tm_sec = systime.wSecond;
res->tm_wday = systime.wDayOfWeek;
res->tm_yday = __mon_yday[iLeap][systime.wMonth] + systime.wDay;
diff --git a/ace/WIN32_Proactor.cpp b/ace/WIN32_Proactor.cpp
index d4e50430e23..67fa1d8db93 100644
--- a/ace/WIN32_Proactor.cpp
+++ b/ace/WIN32_Proactor.cpp
@@ -122,11 +122,7 @@ int
ACE_WIN32_Proactor::register_handle (ACE_HANDLE handle,
const void *completion_key)
{
-#if defined (ACE_WIN64)
ULONG_PTR comp_key (reinterpret_cast<ULONG_PTR> (completion_key));
-#else
- ULONG comp_key (reinterpret_cast<ULONG> (completion_key));
-#endif /* ACE_WIN64 */
// No locking is needed here as no state changes.
ACE_HANDLE cp = ::CreateIoCompletionPort (handle,
@@ -570,11 +566,7 @@ ACE_WIN32_Proactor::handle_events (unsigned long milli_seconds)
{
ACE_OVERLAPPED *overlapped = 0;
u_long bytes_transferred = 0;
-#if defined (ACE_WIN64)
- ULONG_PTR completion_key = 0;
-#else
- ULONG completion_key = 0;
-#endif /* ACE_WIN64 */
+ ULONG_PTR completion_key = 0;
// Get the next asynchronous operation that completes
BOOL result = ::GetQueuedCompletionStatus (this->completion_port_,
@@ -687,11 +679,8 @@ ACE_WIN32_Proactor::post_completion (ACE_WIN32_Asynch_Result *result)
bytes_transferred = static_cast<DWORD> (result->bytes_transferred ());
completion_key = result->completion_key();
}
-#if defined (ACE_WIN64)
+
ULONG_PTR comp_key (reinterpret_cast<ULONG_PTR> (completion_key));
-#else
- ULONG comp_key (reinterpret_cast<ULONG> (completion_key));
-#endif /* ACE_WIN64 */
// Post a completion
if (::PostQueuedCompletionStatus (this->completion_port_, // completion port
diff --git a/ace/config-vxworks6.1.h b/ace/config-vxworks6.1.h
index f82028529ae..2904a21afb6 100644
--- a/ace/config-vxworks6.1.h
+++ b/ace/config-vxworks6.1.h
@@ -3,10 +3,7 @@
// The following configuration file is designed to work for VxWorks
// 6.1 platforms using one of these compilers:
-// 1) The GNU g++ compiler that is shipped with Tornado 2.2 or newer.
-// 2) The Green Hills 1.8.8 and newer 1.8.9 compilers (not tested
-// already for a long time)
-// 3) The WindRiver Compiler (formerly known as Diab)
+// 1) The GNU g++ compiler that is shipped with VxWorks 6.1
#ifndef ACE_CONFIG_H
#define ACE_CONFIG_H
@@ -266,6 +263,12 @@
# define ACE_HAS_PENTIUM
#endif
+// VxWorks defines the CPU define MAP, undef it to prevent problems with
+// application code
+#if defined (MAP)
+#undef MAP
+#endif /* MAP */
+
#if !defined (ACE_NEEDS_HUGE_THREAD_STACKSIZE)
# define ACE_NEEDS_HUGE_THREAD_STACKSIZE 65536
#endif /* ACE_NEEDS_HUGE_THREAD_STACKSIZE */
diff --git a/bin/MakeProjectCreator/modules/BorlandProjectCreator.pm b/bin/MakeProjectCreator/modules/BorlandProjectCreator.pm
index 2c45a070d29..167c91ac295 100644
--- a/bin/MakeProjectCreator/modules/BorlandProjectCreator.pm
+++ b/bin/MakeProjectCreator/modules/BorlandProjectCreator.pm
@@ -13,10 +13,11 @@ package BorlandProjectCreator;
use strict;
use ProjectCreator;
+use WinProjectBase;
use File::Basename;
use vars qw(@ISA);
-@ISA = qw(ProjectCreator);
+@ISA = qw(WinProjectBase ProjectCreator);
# ************************************************************
# Subroutine Section
diff --git a/etc/tao.doxygen b/etc/tao.doxygen
index a1b094b5be6..6562d4ba9e6 100644
--- a/etc/tao.doxygen
+++ b/etc/tao.doxygen
@@ -123,7 +123,12 @@ EXPAND_AS_DEFINED = ACE_RCSID \
ACE_UNIMPLEMENTED_FUNC \
ACE_CACHE_MAP_MANAGER \
ACE_THROW_SPEC \
- TAO_NAMESPACE
+ ACE_ENV_ARG_DECL_WITH_DEFAULTS \
+ ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS \
+ ACE_ENV_ARG_DECL \
+ ACE_ENV_SINGLE_ARG_DECL \
+ ACE_ENV_SINGLE_ARG_PARAMETER \
+ ACE_ENV_ARG_PARAMETER
#---------------------------------------------------------------------------
# Configuration::addtions related to external references
diff --git a/examples/Reactor/Misc/test_demuxing.cpp b/examples/Reactor/Misc/test_demuxing.cpp
index 621e5f72f1c..6badd849757 100644
--- a/examples/Reactor/Misc/test_demuxing.cpp
+++ b/examples/Reactor/Misc/test_demuxing.cpp
@@ -151,7 +151,7 @@ Sig_Handler::handle_signal (int signum, siginfo_t *, ucontext_t *)
ACE_Reactor::end_event_loop ();
break;
default:
- ACE_ASSERT (!"invalid signal");
+ ACE_ERROR_RETURN ((LM_ERROR, "invalid signal"), -1);
break;
/* NOTREACHED */
}
diff --git a/include/makeinclude/platform_linux_icc.GNU b/include/makeinclude/platform_linux_icc.GNU
index 306bfb0df35..55945eac5ab 100644
--- a/include/makeinclude/platform_linux_icc.GNU
+++ b/include/makeinclude/platform_linux_icc.GNU
@@ -105,15 +105,18 @@ ifneq ($(SYSARCH),ia64)
endif
# Disable floating point optimizer solves problem with
-# min/max float values in the TAO_IDL compiler tests when
-# optimizations are enabled. If these options are not
-# passed we can get overflows when testing min/max
+# min/max float values in the TAO_IDL compiler tests
+# If these options are not passed we can get overflows
+# when testing min/max
+ifeq ($(SYSARCH),ia64)
+ CPPFLAGS += -mp
+else
+ CPPFLAGS += -fp-model double
+endif
+
ifeq ($(optimize),0)
- ifeq ($(SYSARCH),ia64)
- CPPFLAGS += -mp
- else
- CPPFLAGS += -fp-model double
- endif
+ # Disable all optimizing in code
+ CPPFLAGS += -O0
endif
PIC = -fPIC
diff --git a/tests/Buffer_Stream_Test.cpp b/tests/Buffer_Stream_Test.cpp
index 282b0f928fc..87577a33fde 100644
--- a/tests/Buffer_Stream_Test.cpp
+++ b/tests/Buffer_Stream_Test.cpp
@@ -113,7 +113,7 @@ Common_Task::close (u_long exit_status)
int
Supplier::svc (void)
{
- ACE_Message_Block *mb;
+ ACE_Message_Block *mb = 0;
// Send one message for each letter of the alphabet, then send an empty
// message to mark the end.
@@ -161,7 +161,7 @@ Consumer::svc (void)
ACE_Message_Block *mb = 0;
int result;
const char *c = ACE_ALPHABET;
- char *output;
+ char *output = 0;
// Keep looping, reading a message out of the queue, until we
// timeout or get a message with a length == 0, which signals us to
@@ -169,7 +169,7 @@ Consumer::svc (void)
for (;;)
{
- this->timeout_.sec (ACE_OS::time (0) + 4); // Wait for upto 4 seconds
+ this->timeout_.set (ACE_OS::time (0) + 4); // Wait for upto 4 seconds
result = this->getq (mb, &this->timeout_);
@@ -208,8 +208,8 @@ run_main (int, ACE_TCHAR *[])
#if defined (ACE_HAS_THREADS)
// Control hierachically-related active objects.
MT_Stream stream;
- MT_Module *cm;
- MT_Module *sm;
+ MT_Module *cm = 0;
+ MT_Module *sm = 0;
// Allocate the Consumer and Supplier modules.
ACE_NEW_RETURN (cm, MT_Module (ACE_TEXT ("Consumer"), new Consumer), -1);
diff --git a/tests/Basic_Types_Test.cpp b/tests/Basic_Types_Test.cpp
index 7df2604225e..90fbf04a991 100644
--- a/tests/Basic_Types_Test.cpp
+++ b/tests/Basic_Types_Test.cpp
@@ -133,17 +133,17 @@ run_main (int, ACE_TCHAR *[])
errors += check (ACE_TEXT ("sizeof (ACE_UINT64) is %u%s"),
sizeof (ACE_UINT64), 8);
- // ACE assumes sizeof (ptr_arith_t) == sizeof (void*)
- if (sizeof (ptr_arith_t) == sizeof (void *))
- ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("sizeof (ptr_arith_t) == sizeof (void*)\n")));
+ // ACE assumes sizeof (ptrdiff_t) == sizeof (void*)
+ if (sizeof (ptrdiff_t) == sizeof (void *))
+ ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("sizeof (ptrdiff_t) == sizeof (void*)\n")));
else
- ACE_ERROR ((LM_ERROR, ACE_TEXT ("sizeof (ptr_arith_t) != sizeof (void*)\n")));
+ ACE_ERROR ((LM_ERROR, ACE_TEXT ("sizeof (ptrdiff_t) != sizeof (void*)\n")));
- // ACE assumes sizeof (ptr_arith_t) >= sizeof (a_function_pointer)
- if (sizeof (ptr_arith_t) >= sizeof (a_function_pointer))
- ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("sizeof (ptr_arith_t) >= sizeof (a_function_pointer)\n")));
+ // ACE assumes sizeof (ptrdiff_t) >= sizeof (a_function_pointer)
+ if (sizeof (ptrdiff_t) >= sizeof (a_function_pointer))
+ ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("sizeof (ptrdiff_t) >= sizeof (a_function_pointer)\n")));
else
- ACE_ERROR ((LM_ERROR, ACE_TEXT ("sizeof (ptr_arith_t) < sizeof (a_function_pointer)\n")));
+ ACE_ERROR ((LM_ERROR, ACE_TEXT ("sizeof (ptrdiff_t) < sizeof (a_function_pointer)\n")));
#if defined (ACE_LITTLE_ENDIAN)
ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("little endian\n")));